.. redirect-from:: /users/prev_whats_new/github_stats_3.0.3

.. _github-stats-3-0-3:

GitHub statistics for 3.0.3 (Feb 28, 2019)
==========================================

GitHub statistics for 2018/11/10 (tag: v3.0.2) - 2019/02/28

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 14 issues and merged 92 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/40?closed=1>`__

The following 19 authors contributed 157 commits.

* Antony Lee
* Christer Jensen
* Christoph Gohlke
* David Stansby
* Elan Ernest
* Elliott Sales de Andrade
* ImportanceOfBeingErnest
* James Adams
* Jody Klymak
* Johannes H. Jensen
* Matthias Geier
* MeeseeksMachine
* Molly Rossow
* Nelle Varoquaux
* Paul Ivanov
* Pierre Thibault
* Thomas A Caswell
* Tim Hoffmann
* Tobia De Koninck

GitHub issues and pull requests:

Pull Requests (92):

* :ghpull:`13493`: V3.0.3 prep
* :ghpull:`13491`: V3.0.x pi
* :ghpull:`13460`: Backport PR #13455 on branch v3.0.x (BLD: only try to get freetype src if src does not exist)
* :ghpull:`13461`: Backport PR #13426 on branch v3.0.x (FIX: bbox_inches='tight' with only non-finite bounding boxes)
* :ghpull:`13426`: FIX: bbox_inches='tight' with only non-finite bounding boxes
* :ghpull:`13453`: Backport PR #13451 on branch v3.0.x (MNT: fix logic error where we never try the second freetype URL)
* :ghpull:`13451`: MNT: fix logic error where we never try the second freetype URL
* :ghpull:`13446`: Merge pull request #11246 from anntzer/download-jquery
* :ghpull:`13437`: Backport PR #13436 on branch v3.0.x (Add get/set_in_layout to artist API docs.)
* :ghpull:`13436`: Add get/set_in_layout to artist API docs.
* :ghpull:`13432`: Really fix ArtistInspector.get_aliases
* :ghpull:`13416`: Backport PR #13405 on branch v3.0.x (Fix imshow()ing PIL-opened images.)
* :ghpull:`13418`: Backport PR #13412 and #13337 on branch v3.0.x
* :ghpull:`13412`: CI: add additional qt5 deb package on travis
* :ghpull:`13370`: Backport PR #13367 on branch v3.0.x (DOC: fix note of what version hold was deprecated in (2.0 not 2.1))
* :ghpull:`13366`: Backport PR #13365 on branch v3.0.x (Fix gcc warning)
* :ghpull:`13365`: Fix gcc warning
* :ghpull:`13347`: Backport PR #13289 on branch v3.0.x (Fix unhandled C++ exception)
* :ghpull:`13349`: Backport PR #13234 on branch v3.0.x
* :ghpull:`13281`: MAINT install of pinned vers for travis
* :ghpull:`13289`: Fix unhandled C++ exception
* :ghpull:`13345`: Backport PR #13333 on branch v3.0.x (Fix possible leak of return of PySequence_GetItem.)
* :ghpull:`13333`: Fix possible leak of return of PySequence_GetItem.
* :ghpull:`13337`: Bump to flake8 3.7.
* :ghpull:`13340`: Backport PR #12398 on branch v3.0.x (CI: Don't run AppVeyor/Travis for doc backport branches.)
* :ghpull:`13317`: Backport PR #13316 on branch v3.0.x (Put correct version in constrained layout tutorial)
* :ghpull:`13308`: Backport PR #12678 on branch v3.0.x
* :ghpull:`12678`: FIX: properly set tz for YearLocator
* :ghpull:`13291`: Backport PR #13287 on branch v3.0.x (Fix unsafe use of NULL pointer)
* :ghpull:`13290`: Backport PR #13288 on branch v3.0.x (Fix potential memory leak)
* :ghpull:`13287`: Fix unsafe use of NULL pointer
* :ghpull:`13288`: Fix potential memory leak
* :ghpull:`13273`: Backport PR #13272 on branch v3.0.x (DOC Better description of inset locator and colorbar)
* :ghpull:`12812`: Backport PR #12809 on branch v3.0.x (Fix TypeError when calculating tick_values)
* :ghpull:`13245`: Backport PR #13244 on branch v3.0.x (Fix typo)
* :ghpull:`13176`: Backport PR #13047 on branch v3.0.x (Improve docs on contourf extend)
* :ghpull:`13215`: Backport PR #13212 on branch v3.0.x (Updated the docstring for pyplot.figure to list floats as the type for figsize argument)
* :ghpull:`13158`: Backport PR #13150 on branch v3.0.x (Remove unused add_dicts from example.)
* :ghpull:`13157`: Backport PR #13152 on branch v3.0.x (DOC: Add explanatory comment for colorbar with axes divider example)
* :ghpull:`13221`: Backport PR #13194 on branch v3.0.x (TST: Fix incorrect call to pytest.raises.)
* :ghpull:`13230`: Backport PR #13226 on branch v3.0.x (Avoid triggering warnings in mandelbrot example.)
* :ghpull:`13216`: Backport #13205 on branch v3.0.x (Add xvfb service to travis)
* :ghpull:`13194`: TST: Fix incorrect call to pytest.raises.
* :ghpull:`13212`: Updated the docstring for pyplot.figure to list floats as the type for figsize argument
* :ghpull:`13205`: Add xvfb service to travis
* :ghpull:`13204`: Add xvfb service to travis
* :ghpull:`13175`: Backport PR #13015 on branch v3.0.x (Enable local doc building without git installation)
* :ghpull:`13047`: Improve docs on contourf extend
* :ghpull:`13015`: Enable local doc building without git installation
* :ghpull:`13159`: Revert "Pin pytest to <3.8 (for 3.0.x)"
* :ghpull:`13150`: Remove unused add_dicts from example.
* :ghpull:`13152`: DOC: Add explanatory comment for colorbar with axes divider example
* :ghpull:`13085`: Backport PR #13081 on branch v3.0.x (DOC: forbid a buggy version of pillow for building docs)
* :ghpull:`13082`: Backport PR #13080 on branch v3.0.x (Pin pillow to < 5.4 to fix doc build)
* :ghpull:`13054`: Backport PR #13052 on branch v3.0.x (Small bug fix in image_slices_viewer)
* :ghpull:`13052`: Small bug fix in image_slices_viewer
* :ghpull:`13036`: Backport PR #12949 on branch v3.0.x (Update docstring of Axes3d.scatter)
* :ghpull:`12949`: Update docstring of Axes3d.scatter
* :ghpull:`13004`: Backport PR #13001: Update windows build instructions
* :ghpull:`13011`: Backport PR #13006 on branch v3.0.x (Add category module to docs)
* :ghpull:`13009`: Fix dependencies for travis build with python 3.5
* :ghpull:`13006`: Add category module to docs
* :ghpull:`13001`: Update windows build instructions
* :ghpull:`12996`: Fix return type in 3D scatter docs
* :ghpull:`12972`: Backport PR #12929 on branch v3.0.x (FIX: skip gtk backend if gobject but not pygtk is installed)
* :ghpull:`12596`: Use sudo:true for nightly builds.
* :ghpull:`12929`: FIX: skip gtk backend if gobject but not pygtk is installed
* :ghpull:`12965`: Backport PR #12960 on branch v3.0.x (Remove animated=True from animation docs)
* :ghpull:`12964`: Backport PR #12938 on branch v3.0.x (Fix xtick.minor.visible only acting on the xaxis)
* :ghpull:`12938`: Fix xtick.minor.visible only acting on the xaxis
* :ghpull:`12937`: Backport PR #12914 on branch 3.0.x: Fix numpydoc formatting
* :ghpull:`12914`: Fix numpydoc formatting
* :ghpull:`12923`: Backport PR #12921 on branch v3.0.x (Fix documentation of vert parameter of Axes.bxp)
* :ghpull:`12921`: Fix documentation of vert parameter of Axes.bxp
* :ghpull:`12912`: Backport PR #12878 on branch v3.0.2-doc (Pin pytest to <3.8 (for 3.0.x))
* :ghpull:`12906`: Backport PR #12774 on branch v3.0.x
* :ghpull:`12774`: Cairo backend: Fix alpha render of collections
* :ghpull:`12854`: Backport PR #12835 on branch v3.0.x (Don't fail tests if cairo dependency is not installed.)
* :ghpull:`12896`: Backport PR #12848 on branch v3.0.x (Fix spelling of the name Randall Munroe)
* :ghpull:`12894`: Backport PR #12890 on branch v3.0.x (Restrict postscript title to ascii.)
* :ghpull:`12838`: Backport PR #12795 on branch v3.0.x (Fix Bezier degree elevation formula in backend_cairo.)
* :ghpull:`12843`: Backport PR #12824 on branch v3.0.x
* :ghpull:`12890`: Restrict postscript title to ascii.
* :ghpull:`12878`: Pin pytest to <3.8 (for 3.0.x)
* :ghpull:`12870`: Backport PR #12869 on branch v3.0.x (Fix latin-1-ization of Title in eps.)
* :ghpull:`12869`: Fix latin-1-ization of Title in eps.
* :ghpull:`12835`: Don't fail tests if cairo dependency is not installed.
* :ghpull:`12848`: Fix spelling of the name Randall Munroe
* :ghpull:`12795`: Fix Bezier degree elevation formula in backend_cairo.
* :ghpull:`12824`: Add missing datestr2num to docs
* :ghpull:`12791`: Backport PR #12790 on branch v3.0.x (Remove ticks and titles from tight bbox tests.)
* :ghpull:`12790`: Remove ticks and titles from tight bbox tests.

Issues (14):

* :ghissue:`10360`: creating PathCollection proxy artist with %matplotlib inline raises ValueError: cannot convert float NaN to integer
* :ghissue:`13276`: calling annotate with nan values for the position still gives error after 3.0.2
* :ghissue:`13450`: Issues with jquery download caching
* :ghissue:`13223`: label1On set to true when axis.tick_params(axis='both', which='major', length=5)
* :ghissue:`13311`: docs unclear on status of constraint layout
* :ghissue:`12675`: Off-by-one bug in annual axis labels when localized time crosses year boundary
* :ghissue:`13208`: Wrong argument type for figsize in documentation for figure
* :ghissue:`13201`: test_backend_qt tests failing
* :ghissue:`13013`: v3.0.2 local html docs "git describe" error
* :ghissue:`13051`: Missing self in image_slices_viewer
* :ghissue:`12920`: Incorrect return type in mplot3d documentation
* :ghissue:`12907`: Tiny typo in documentation of matplotlib.figure.Figure.colorbar
* :ghissue:`12892`: GTK3Cairo Backend Legend TypeError
* :ghissue:`12815`: DOC: matplotlib.dates datestr2num function documentation is missing
